@@ -7,7 +7,6 @@ from pandas.io.parsers import TextParser
 from pandas.errors import EmptyDataError
 from typing import Mapping, Any
 from .util import DEFAULT_TIMEOUT, DEFAULT_CHECK_INTERVAL, DEFAULT_FAIL_WHEN_LOCKED, LOCK_METHOD
-from copy import deepcopy
 
 
 class NotFunctionError(Exception):
@@ -25,13 +24,13 @@ class Streams(object):
     def __init__(self):
         self.streams = dict()
 
-    def add_stream(self, engine, handler, buffer, **kwargs):
+    def add_stream(self, engine, handler, buffer):
         assert engine in self.__engines, f"Engine {engine} not recognized"
 
         if engine not in self.streams.keys():
             self.streams[engine] = list()
 
-        self.streams[engine].append([handler, buffer, kwargs])
+        self.streams[engine].append([handler, buffer])
 
     def clear_streams(self):
         self.streams = dict()
@@ -281,9 +280,9 @@ class FileHandler(object):
             except EmptyDataError:
                 df = DataFrame()
 
-            return deepcopy(df)
+            return df
         else:
-            return deepcopy(DataFrame())
+            return DataFrame()
 
 
 class FileParser(object):
@@ -328,21 +327,20 @@ class FileParser(object):
         else:
             self.__reader = None
 
-    def stream_data(self, buffer=DEFAULTBUFFER, engine='default', **kwargs):
+    def stream_data(self, buffer=DEFAULTBUFFER, engine='default'):
         """
         Stream data into chunks
 
         :param buffer: Number of lines per chunk
         :param engine: [Optional] xmlread, csv, open, xlrd, openpyxl, odf, pyxlsb, or default
-        :param kwargs: [Optional] Kwarg values you wish to pass through
         :var data: Either dataframe or list of data
         :var row_start: Row number for first row of data
         :var row_end: Row number for last row of data
-        :var **kwargs: Kwarg values that you specify in stream_data wrapper
+        :var **kwargs: Kwarg values provided by parse commands
         """
 
         def registerhandler(handler):
-            self.__streams.add_stream(engine, handler, buffer, **kwargs)
+            self.__streams.add_stream(engine, handler, buffer)
             return handler
 
         return registerhandler
@@ -354,7 +352,7 @@ class FileParser(object):
                     usecols=None, squeeze=False, converters=None, dtype=None, engine=None, true_values=None,
                     false_values=None, skiprows=0, nrows=0, na_values=None, keep_default_na=True, na_filter=True,
                     verbose=False, parse_dates=False, date_parser=None, thousands=None, comment=None,
-                    convert_float=True, mangle_dupe_cols=True, truncate=False):
+                    convert_float=True, mangle_dupe_cols=True, truncate=False, **kwargs):
 
         """
         Parses excel files into a dataframe or stream
@@ -389,6 +387,7 @@ class FileParser(object):
         :param convert_float: Convert integral floats to int (i.e., 1.0 –> 1)
         :param mangle_dupe_cols: Duplicate columns will be specified as ‘X’, ‘X.1’, …’X.N’, rather than ‘X’…’X’
         :param truncate: Truncates excel file
+        :param kwargs: kwarg values
         :return: Dataframe
         """
 
@@ -402,21 +401,22 @@ class FileParser(object):
                                                  comment=comment, skipfooter=0, convert_float=convert_float,
                                                  mangle_dupe_cols=mangle_dupe_cols, converters=converters,
                                                  keep_default_na=keep_default_na, na_filter=na_filter,
-                                                 truncate=truncate)
+                                                 truncate=truncate, **kwargs)
         self.reader.streams = self.__streams[obj.engine] + self.__streams['default']
         return self.reader.parse()
 
-    def parse_xml(self, file_path, xmlns_rs, dict_var=None):
+    def parse_xml(self, file_path, xmlns_rs, dict_var=None, **kwargs):
         """
         Parses XML file into dataframe or stream
 
         :param file_path: File path to the file being read
         :param xmlns_rs: xmlns_rs header needed to read xml file (At top of xml file)
         :param dict_var: [Optional] (dict) Append data into dict variable
+        :param kwargs: kwarg values
         :return: dataframe
         """
 
-        self.reader = self.__engines['xmlread'](file_path=file_path, xmlns_rs=xmlns_rs, dict_var=dict_var)
+        self.reader = self.__engines['xmlread'](file_path=file_path, xmlns_rs=xmlns_rs, dict_var=dict_var, **kwargs)
         self.reader.streams = self.__streams['xmlread'] + self.__streams['default']
         return self.reader.parse()
 
@@ -433,7 +433,7 @@ class FileParser(object):
         self.reader.write()
 
     def parse_open(self, file_path, mode='a', timeout=DEFAULT_TIMEOUT, check_interval=DEFAULT_CHECK_INTERVAL,
-                   fail_when_locked=DEFAULT_FAIL_WHEN_LOCKED, flags=LOCK_METHOD, **file_open_kwargs):
+                   fail_when_locked=DEFAULT_FAIL_WHEN_LOCKED, flags=LOCK_METHOD, **kwargs):
         """
         Opens a Txt or etc... file and returns a file open object or streams into buffered data
 
@@ -443,40 +443,41 @@ class FileParser(object):
         :param check_interval: Check interval
         :param fail_when_locked: Type of failure when locked
         :param flags: Flags
-        :param file_open_kwargs: Kwargs
+        :param kwargs: kwarg values
         :return: open object for reading
         """
 
         self.reader = self.__engines['open'](file_path=file_path, mode=mode, timeout=timeout,
                                              check_interval=check_interval, fail_when_locked=fail_when_locked,
-                                             flags=flags, **file_open_kwargs)
+                                             flags=flags, **kwargs)
         self.reader.streams = self.__streams['open'] + self.__streams['default']
         return self.reader.parse()
 
-    def parse_csv(self, file_path, dialect=None, truncate=False, **fmtparams):
+    def parse_csv(self, file_path, dialect=None, truncate=False, **kwargs):
         """
         Parses CSV data into data
 
         :param file_path: File path to the file being read
         :param dialect: dialect for csv reading
         :param truncate: Truncates excel file
-        :param fmtparams: Python format parameters
+        :param kwargs: Python format parameters
         :return: data
         """
 
-        self.reader = self.__engines['csv'](file_path=file_path, dialect=dialect, truncate=truncate, **fmtparams)
+        self.reader = self.__engines['csv'](file_path=file_path, dialect=dialect, truncate=truncate, **kwargs)
         self.reader.streams = self.__streams['csv'] + self.__streams['default']
         return self.reader.parse()
 
-    def parse_json(self, file_path):
+    def parse_json(self, file_path, **kwargs):
         """
         Reads json into python objects or stream it in chunks
 
         :param file_path: File path to the file being read
+        :param kwargs: kwarg values
         :return: python objects
         """
 
-        self.reader = self.__engines['json'](file_path=file_path)
+        self.reader = self.__engines['json'](file_path=file_path, **kwargs)
         self.reader.streams = self.__streams['json'] + self.__streams['default']
         return self.reader.parse()
 
@@ -484,7 +485,6 @@ class FileParser(object):
         self.clear_streams()
         self.__streams = None
         self.__reader = None
-        self.__engines = None
 
 
 def is_an_xml(xml_file):
