@@ -27,8 +27,8 @@ class OpenPYXLReader(FileHandler):
 
     def parse(self):
         if self.streams:
-            for handler, buffer, kwargs in self.streams:
-                self.__parse(handler=handler, buffer=buffer, **kwargs)
+            for handler, buffer in self.streams:
+                self.__parse(handler=handler, buffer=buffer)
         else:
             return self.__parse()
 
@@ -53,7 +53,7 @@ class OpenPYXLReader(FileHandler):
 
         return sheets
 
-    def __parse(self, handler=None, buffer=None, **kwargs):
+    def __parse(self, handler=None, buffer=None):
         sheets = dict()
 
         try:
@@ -66,7 +66,7 @@ class OpenPYXLReader(FileHandler):
                         xls_ws = xls_file[tab]
 
                         if handler:
-                            self.__openpyxl_sheet(sheet=xls_ws, handler=handler, buffer=buffer, **kwargs)
+                            self.__openpyxl_sheet(sheet=xls_ws, handler=handler, buffer=buffer)
                         else:
                             sheets[tab] = self.__openpyxl_sheet(sheet=xls_ws, handler=handler, buffer=buffer)
 
@@ -87,7 +87,7 @@ class OpenPYXLReader(FileHandler):
         if sheets:
             return sheets
 
-    def __openpyxl_sheet(self, sheet, handler=None, buffer=None, **kwargs):
+    def __openpyxl_sheet(self, sheet, handler=None, buffer=None):
         import openpyxl
 
         version = LooseVersion(get_version(openpyxl))
@@ -116,7 +116,7 @@ class OpenPYXLReader(FileHandler):
                 if handler and buffer < len(data):
                     data = self.__read_only_fix(data, version, is_readonly)
                     df = self.convert_data(data)
-                    handler(self.file_path, df, row_number - len(df) + 1, row_number, **kwargs)
+                    handler(self.file_path, df, row_number - len(df) + 1, row_number, **self.kwargs)
                     data.clear()
                     data.append(header)
                     last_row_with_data = -1
@@ -130,7 +130,7 @@ class OpenPYXLReader(FileHandler):
 
         if not df.empty and handler:
             row_number -= 1
-            handler(self.file_path, df, row_number - len(df) + 1, row_number, **kwargs)
+            handler(self.file_path, df, row_number - len(df) + 1, row_number, **self.kwargs)
         elif handler is None:
             return df
 
@@ -192,12 +192,12 @@ class ODFReader(FileHandler):
 
     def parse(self):
         if self.streams:
-            for handler, buffer, kwargs in self.streams:
-                self.__parse(handler=handler, buffer=buffer, **kwargs)
+            for handler, buffer in self.streams:
+                self.__parse(handler=handler, buffer=buffer)
         else:
             return self.__parse()
 
-    def __parse(self, handler=None, buffer=None, **kwargs):
+    def __parse(self, handler=None, buffer=None):
         from odf.opendocument import load
         from odf.table import Table
 
@@ -210,7 +210,7 @@ class ODFReader(FileHandler):
 
                 if not self.__sheet_names or tab.lower() in self.__sheet_names:
                     if handler:
-                        self.__odf_sheet(sheet=xls_ws, handler=handler, buffer=buffer, **kwargs)
+                        self.__odf_sheet(sheet=xls_ws, handler=handler, buffer=buffer)
                     else:
                         sheets[tab] = self.__odf_sheet(sheet=xls_ws, handler=handler, buffer=buffer)
         finally:
@@ -219,7 +219,7 @@ class ODFReader(FileHandler):
         if sheets:
             return sheets
 
-    def __odf_sheet(self, sheet, handler=None, buffer=None, **kwargs):
+    def __odf_sheet(self, sheet, handler=None, buffer=None):
         from odf.table import CoveredTableCell, TableCell, TableRow
 
         covered_cell_name = CoveredTableCell().qname
@@ -276,7 +276,7 @@ class ODFReader(FileHandler):
                 if handler and buffer < len(table):
                     table = self.__fix_table(table)
                     df = self.convert_data(table)
-                    handler(self.file_path, df, row_number - len(df) + 1, row_number, **kwargs)
+                    handler(self.file_path, df, row_number - len(df) + 1, row_number, **self.kwargs)
                     table.clear()
                     table.append(header)
 
@@ -288,7 +288,7 @@ class ODFReader(FileHandler):
 
         if not df.empty and handler:
             row_number -= 1
-            handler(self.file_path, df, row_number - len(df) + 1, row_number, **kwargs)
+            handler(self.file_path, df, row_number - len(df) + 1, row_number, **self.kwargs)
         elif not handler:
             return df
 
@@ -399,12 +399,12 @@ class XLRDReader(FileHandler):
 
     def parse(self):
         if self.streams:
-            for handler, buffer, kwargs in self.streams:
-                self.__parse(handler=handler, buffer=buffer, **kwargs)
+            for handler, buffer in self.streams:
+                self.__parse(handler=handler, buffer=buffer)
         else:
             return self.__parse()
 
-    def __parse(self, handler=None, buffer=None, **kwargs):
+    def __parse(self, handler=None, buffer=None):
         from xlrd import open_workbook
 
         sheets = dict()
@@ -416,19 +416,16 @@ class XLRDReader(FileHandler):
                     xls_ws = xls_file.sheet_by_name(tab)
 
                     if handler:
-                        self.__xlrd_sheet(sheet=xls_ws, handler=handler, buffer=buffer, **kwargs)
+                        self.__xlrd_sheet(sheet=xls_ws, handler=handler, buffer=buffer)
                     else:
                         sheets[tab] = self.__xlrd_sheet(sheet=xls_ws, handler=handler, buffer=buffer)
         finally:
-            if self.__xls_file and hasattr(self.__xls_file, 'close'):
-                self.__xls_file.close()
-            else:
-                self.__xls_file = None
+            self.__xls_file = None
 
         if sheets:
             return sheets
 
-    def __xlrd_sheet(self, sheet, handler=None, buffer=None, **kwargs):
+    def __xlrd_sheet(self, sheet, handler=None, buffer=None):
         data: List[List[Scalar]] = []
         row_number = 0
         header = None
@@ -446,7 +443,7 @@ class XLRDReader(FileHandler):
 
                 if handler and len(data) <= buffer:
                     df = self.convert_data(data)
-                    handler(df, row_number - len(df) + 1, row_number, **kwargs)
+                    handler(df, row_number - len(df) + 1, row_number, **self.kwargs)
                     data.clear()
                     data.append(header)
 
@@ -457,7 +454,7 @@ class XLRDReader(FileHandler):
 
         if not df.empty and handler:
             row_number -= 1
-            handler(self.file_path, df, row_number - len(df) + 1, row_number, **kwargs)
+            handler(self.file_path, df, row_number - len(df) + 1, row_number, **self.kwargs)
         elif not handler:
             return df
 
@@ -516,12 +513,12 @@ class PYXLSBReader(FileHandler):
 
     def parse(self):
         if self.streams:
-            for handler, buffer, kwargs in self.streams:
-                self.__parse(handler=handler, buffer=buffer, **kwargs)
+            for handler, buffer in self.streams:
+                self.__parse(handler=handler, buffer=buffer)
         else:
             return self.__parse()
 
-    def __parse(self, handler=None, buffer=None, **kwargs):
+    def __parse(self, handler=None, buffer=None):
         from pyxlsb import open_workbook
 
         sheets = dict()
@@ -533,7 +530,7 @@ class PYXLSBReader(FileHandler):
                     xls_ws = xls_file.get_sheet(tab)
 
                     if handler:
-                        self.__pyxlsb_sheet(sheet=xls_ws, handler=handler, buffer=buffer, **kwargs)
+                        self.__pyxlsb_sheet(sheet=xls_ws, handler=handler, buffer=buffer)
                     else:
                         sheets[tab] = self.__pyxlsb_sheet(sheet=xls_ws, handler=handler, buffer=buffer)
         finally:
@@ -542,7 +539,7 @@ class PYXLSBReader(FileHandler):
         if sheets:
             return sheets
 
-    def __pyxlsb_sheet(self, sheet, handler, buffer, **kwargs):
+    def __pyxlsb_sheet(self, sheet, handler, buffer):
         data: List[List[Scalar]] = []
         row_number = 0
         header = None
@@ -557,7 +554,7 @@ class PYXLSBReader(FileHandler):
 
                 if handler and buffer < len(data):
                     df = self.convert_data(data)
-                    handler(self.file_path, df, row_number - len(df) + 1, row_number, **kwargs)
+                    handler(self.file_path, df, row_number - len(df) + 1, row_number, **self.kwargs)
                     data.clear()
                     data.append(header)
 
@@ -568,7 +565,7 @@ class PYXLSBReader(FileHandler):
 
         if not df.empty and handler:
             row_number -= 1
-            handler(self.file_path, df, row_number - len(df) + 1, row_number, **kwargs)
+            handler(self.file_path, df, row_number - len(df) + 1, row_number, **self.kwargs)
         elif not handler:
             return df
 
